@@ -1,5 +1,5 @@
 #input subject, time, test and ref concentration
 RepNCAdata<-function()
 {
-NCAdata(replicated=TRUE)
+NCAdata(replicated=TRUE, parallel=FALSE)
 }
\ No newline at end of file
