@@ -1,7 +1,7 @@
 about.bear<-function(){
 cat("\n\n")
 cat(" ----------------------------------------------------------------\n\n")
-cat("  bear v2.6.3                                                      \n")
+cat("  bear v2.6.4                                                      \n")
 cat("  http://pkpd.kmu.edu.tw/bear                                      \n")  
 cat("                                                                   \n")  
 cat(" This package is designed to analyze average bioequivalence (ABE)  \n")  
@@ -15,8 +15,7 @@ cat("                                                                   \n")
 cat(" ps. bear will be crashed when it is applied to incomplete         \n")
 cat(" crossover design/data.                                          \n\n")
 cat(" bear was developed by Hsin-ya Lee & Yung-jin Lee.                 \n")
-cat(" contact: Yung-jin Lee <mobilepk@gmail.com>                        \n")
-cat(" Kaohsiung Veterans General Hospital (HY) & ptpc inc. (YJ),        \n")
+cat(" contact: Yung-jin Lee <mobilepk at gmail.com>                     \n")
 cat(" Kaohsiung, Taiwan                                                 \n")
 cat(" bear is under license of GPL-2|GPL-3.                           \n\n")
 cat(" internet resources:                                               \n")
